==> green-core-1.70.1.tgz: package/primitives/form-control-header/form-control-header.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod
} from "../../chunks/chunk.QTSIPXV3.js";
var _handleExtSupTxtSlotChange, handleExtSupTxtSlotChange_fn, _renderExtSupTxtButton, _handleExtSupTxtBtnClick, _renderExtSupTxt, renderExtSupTxt_fn;
import { localized, msg } from "@lit/localize";
import { property, query, state } from "lit/decorators.js";
import { when } from "lit/directives/when.js";
import { GdsButton } from "../../components/button/button.component";
import { GdsCard } from "../../components/card/card.component";
import { IconCircleInfo } from "../../components/icon/icons/circle-info.component";
import { GdsElement } from "../../gds-element";
import {
  gdsCustomElement,
  html
} from "../../utils/helpers/custom-element-scoping";
import { styles } from "./form-control-header.styles";
let GdsFormControlHeader = class extends GdsElement {
  constructor() {
    super(...arguments);
    __privateAdd(this, _handleExtSupTxtSlotChange);
    __privateAdd(this, _renderExtSupTxt);
    this.showExtendedSupportingText = false;
    this._hasExtendedSupportingText = false;
    __privateAdd(this, _renderExtSupTxtButton, () => {
      return html`
      <gds-button
        size="small"
        rank="tertiary"
        label="${msg("Show more information")}"
        gds-aria-expanded="${this.showExtendedSupportingText}"
        @click=${__privateGet(this, _handleExtSupTxtBtnClick)}
      >
        <gds-icon-circle-info ?solid=${this.showExtendedSupportingText} />
      </gds-button>
    `;
    });
    __privateAdd(this, _handleExtSupTxtBtnClick, () => {
      this.showExtendedSupportingText = !this.showExtendedSupportingText;
      this._extendedSupportingText?.style.setProperty(
        "--_max-height",
        this.showExtendedSupportingText ? `${this._extendedSupportingText.scrollHeight}px` : "0"
      );
      this.dispatchEvent(
        new CustomEvent("gds-ui-state", {
          bubbles: true,
          composed: true,
          detail: this.showExtendedSupportingText
        })
      );
    });
  }
  render() {
    return html`
      <div id="label-row">
        <div>
          <slot name="label"></slot>
          <slot name="supporting-text"></slot>
        </div>
        ${when(this._hasExtendedSupportingText, __privateGet(this, _renderExtSupTxtButton))}
      </div>

      ${__privateMethod(this, _renderExtSupTxt, renderExtSupTxt_fn).call(this)}
    `;
  }
};
_handleExtSupTxtSlotChange = new WeakSet();
handleExtSupTxtSlotChange_fn = function(e) {
  this._hasExtendedSupportingText = e.target.assignedElements({ flatten: true }).length > 0;
};
_renderExtSupTxtButton = new WeakMap();
_handleExtSupTxtBtnClick = new WeakMap();
_renderExtSupTxt = new WeakSet();
renderExtSupTxt_fn = function() {
  return html`
      <div
        id="extended-supporting-text"
        aria-hidden="${this.showExtendedSupportingText ? "false" : "true"}"
        ?inert=${!this.showExtendedSupportingText}
      >
        <slot
          name="extended-supporting-text"
          @slotchange=${__privateMethod(this, _handleExtSupTxtSlotChange, handleExtSupTxtSlotChange_fn)}
        ></slot>
      </div>
    `;
};
GdsFormControlHeader.styles = [styles];
__decorateClass([
  property({
    type: Boolean,
    reflect: true
  })
], GdsFormControlHeader.prototype, "showExtendedSupportingText", 2);
__decorateClass([
  state()
], GdsFormControlHeader.prototype, "_hasExtendedSupportingText", 2);
__decorateClass([
  query("#extended-supporting-text")
], GdsFormControlHeader.prototype, "_extendedSupportingText", 2);
GdsFormControlHeader = __decorateClass([
  gdsCustomElement("gds-form-control-header", {
    dependsOn: [GdsButton, GdsCard, IconCircleInfo]
  }),
  localized()
], GdsFormControlHeader);
export {
  GdsFormControlHeader
};

==> green-core-1.71.0.tgz: package/primitives/form-control-header/form-control-header.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod
} from "../../chunks/chunk.QTSIPXV3.js";
var _handleExtSupTxtSlotChange, handleExtSupTxtSlotChange_fn, _renderExtSupTxtButton, _handleExtSupTxtBtnClick, _renderExtSupTxt, renderExtSupTxt_fn;
import { localized, msg } from "@lit/localize";
import { property, query, state } from "lit/decorators.js";
import { when } from "lit/directives/when.js";
import { GdsButton } from "../../components/button/button.component.js";
import { GdsCard } from "../../components/card/card.component.js";
import { IconCircleInfo } from "../../components/icon/icons/circle-info.component.js";
import { GdsElement } from "../../gds-element.js";
import {
  gdsCustomElement,
  html
} from "../../utils/helpers/custom-element-scoping.js";
import { styles } from "./form-control-header.styles";
let GdsFormControlHeader = class extends GdsElement {
  constructor() {
    super(...arguments);
    __privateAdd(this, _handleExtSupTxtSlotChange);
    __privateAdd(this, _renderExtSupTxt);
    this.showExtendedSupportingText = false;
    this._hasExtendedSupportingText = false;
    __privateAdd(this, _renderExtSupTxtButton, () => {
      return html`
      <gds-button
        size="small"
        rank="tertiary"
        label="${msg("Show more information")}"
        gds-aria-expanded="${this.showExtendedSupportingText}"
        @click=${__privateGet(this, _handleExtSupTxtBtnClick)}
      >
        <gds-icon-circle-info ?solid=${this.showExtendedSupportingText} />
      </gds-button>
    `;
    });
    __privateAdd(this, _handleExtSupTxtBtnClick, () => {
      this.showExtendedSupportingText = !this.showExtendedSupportingText;
      this._extendedSupportingText?.style.setProperty(
        "--_max-height",
        this.showExtendedSupportingText ? `${this._extendedSupportingText.scrollHeight}px` : "0"
      );
      this.dispatchEvent(
        new CustomEvent("gds-ui-state", {
          bubbles: true,
          composed: true,
          detail: this.showExtendedSupportingText
        })
      );
    });
  }
  render() {
    return html`
      <div id="label-row">
        <div>
          <slot name="label"></slot>
          <slot name="supporting-text"></slot>
        </div>
        ${when(this._hasExtendedSupportingText, __privateGet(this, _renderExtSupTxtButton))}
      </div>

      ${__privateMethod(this, _renderExtSupTxt, renderExtSupTxt_fn).call(this)}
    `;
  }
};
_handleExtSupTxtSlotChange = new WeakSet();
handleExtSupTxtSlotChange_fn = function(e) {
  this._hasExtendedSupportingText = e.target.assignedElements({ flatten: true }).length > 0;
};
_renderExtSupTxtButton = new WeakMap();
_handleExtSupTxtBtnClick = new WeakMap();
_renderExtSupTxt = new WeakSet();
renderExtSupTxt_fn = function() {
  return html`
      <div
        id="extended-supporting-text"
        aria-hidden="${this.showExtendedSupportingText ? "false" : "true"}"
        ?inert=${!this.showExtendedSupportingText}
      >
        <slot
          name="extended-supporting-text"
          @slotchange=${__privateMethod(this, _handleExtSupTxtSlotChange, handleExtSupTxtSlotChange_fn)}
        ></slot>
      </div>
    `;
};
GdsFormControlHeader.styles = [styles];
__decorateClass([
  property({
    type: Boolean,
    reflect: true
  })
], GdsFormControlHeader.prototype, "showExtendedSupportingText", 2);
__decorateClass([
  state()
], GdsFormControlHeader.prototype, "_hasExtendedSupportingText", 2);
__decorateClass([
  query("#extended-supporting-text")
], GdsFormControlHeader.prototype, "_extendedSupportingText", 2);
GdsFormControlHeader = __decorateClass([
  gdsCustomElement("gds-form-control-header", {
    dependsOn: [GdsButton, GdsCard, IconCircleInfo]
  }),
  localized()
], GdsFormControlHeader);
export {
  GdsFormControlHeader
};
